@@ -1,15 +1,17 @@
 use strict;
 use warnings;
+
 package Catalyst::Model::SWISH;
 use base 'Catalyst::Model';
 use Carp;
 use SWISH::API::Object;
 use NEXT;
+use Catalyst::Utils;
 use Data::Pageset;
 use Time::HiRes;
 use Sort::SQL;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 __PACKAGE__->mk_accessors(qw( swish swish_error context ));
 
@@ -97,47 +99,41 @@ Constructor is called automatically by Catalyst at startup.
 
 =cut
 
-
-sub ACCEPT_CONTEXT
-{
-    my ($self, $c, @args) = @_;
-    my $new = bless({%$self}, ref $self);
+sub ACCEPT_CONTEXT {
+    my ( $self, $c, @args ) = @_;
+    my $new = bless( {%$self}, ref $self );
     $new->context($c);
     return $new;
 }
 
-
-sub new
-{
-    my ($class, $c) = @_;
-    my $self = $class->NEXT::new($c);
+sub new {
+    my ( $class, $c ) = @_;
+    my $self   = $class->NEXT::new($c);
     my %config = (
-                  indexes => $self->config->{indexes}
-                    || $c->config->{$class}->{indexes}
-                    || $c->config->{home} . '/index.swish-e',
-                  pages_per_set => $self->config->{pages_per_set} || 10,
-                  %{$self->config()},
-                  %{$c->config->{$class}},
-                 );
+        indexes => $self->config->{indexes}
+            || $c->config->{$class}->{indexes}
+            || $c->config->{home} . '/index.swish-e',
+        pages_per_set => $self->config->{pages_per_set} || 10
+    );
+
+    Catalyst::Utils::merge_hashes( \%config, $self->config ) if $self->config;
+    Catalyst::Utils::merge_hashes( \%config, $c->config->{$class} )
+        if exists $c->config->{$class};
 
     # page_size == 0 is a valid value, so we must use defined()
-    unless (defined $config{page_size})
-    {
-        if (defined $self->config->{page_size})
-        {
+    unless ( defined $config{page_size} ) {
+        if ( defined $self->config->{page_size} ) {
             $config{page_size} = $self->config->{page_size};
         }
-        elsif (defined $c->config->{$class}->{page_size})
-        {
+        elsif ( defined $c->config->{$class}->{page_size} ) {
             $config{page_size} = $c->config->{$class}->{page_size};
         }
-        else
-        {
+        else {
             $config{page_size} = 10;
         }
     }
 
-    $self->config(\%config);
+    $self->config( \%config );
     $self->connect;
     return $self;
 }
@@ -212,117 +208,107 @@ Low value for C<limit_to>.
 
 =cut
 
-sub search
-{
+sub search {
     my $self = shift;
     my $c    = $self->context;
     my %opts = @_;
 
     $opts{query} or croak "query required";
-    $opts{page}          ||= 1;
-    $opts{page_size} = defined($opts{page_size}) ?
-        $opts{page_size} : $self->config->{page_size};
+    $opts{page} ||= 1;
+    $opts{page_size}
+        = defined( $opts{page_size} )
+        ? $opts{page_size}
+        : $self->config->{page_size};
     $opts{pages_per_set} ||= $self->config->{pages_per_set};
 
-    my $start_time = [Time::HiRes::gettimeofday()];
+    my $start_time = [ Time::HiRes::gettimeofday() ];
     my $search     = $self->swish->new_search_object;
-    if ($self->_check_err)
-    {
-        $c->error($self->swish_error);
+    if ( $self->_check_err ) {
+        $c->error( $self->swish_error );
         return;
     }
 
-    if ($opts{limit_to})
-    {
-        defined $opts{limit_high} or croak "limit_high required with limit_to";
-        defined $opts{limit_low}  or croak "limit_low required with limit_to";
+    if ( $opts{limit_to} ) {
+        defined $opts{limit_high}
+            or croak "limit_high required with limit_to";
+        defined $opts{limit_low} or croak "limit_low required with limit_to";
 
-        $search->set_search_limit($opts{limit_to}, $opts{limit_low},
-                                  $opts{limit_high});
-        if ($self->_check_err)
-        {
-            $c->error($self->swish_error);
+        $search->set_search_limit( $opts{limit_to}, $opts{limit_low},
+            $opts{limit_high} );
+        if ( $self->_check_err ) {
+            $c->error( $self->swish_error );
             return;
         }
     }
-    if ($opts{order_by})
-    {
-        $search->set_sort($opts{order_by});
+    if ( $opts{order_by} ) {
+        $search->set_sort( $opts{order_by} );
     }
 
-    my $results = $search->execute($opts{query});
-    if ($self->_check_err)
-    {
-        $c->error($self->swish_error);
+    my $results = $search->execute( $opts{query} );
+    if ( $self->_check_err ) {
+        $c->error( $self->swish_error );
         return;
     }
     my $search_time = sprintf(
-                              '%0.4f',
-                              Time::HiRes::tv_interval(
-                                      $start_time, [Time::HiRes::gettimeofday()]
-                              )
-                             );
+        '%0.4f',
+        Time::HiRes::tv_interval(
+            $start_time, [ Time::HiRes::gettimeofday() ]
+        )
+    );
 
     my @r;
-    my $start       = ($opts{page} - 1) * $opts{page_size};
-    my $build_start = [Time::HiRes::gettimeofday()];
+    my $start       = ( $opts{page} - 1 ) * $opts{page_size};
+    my $build_start = [ Time::HiRes::gettimeofday() ];
     $results->seek_result($start) unless $start > $results->hits;
     my $count = 0;
-    while (my $r = $results->next_result)
-    {
-        push(@r, $r);
-        if (++$count >= $opts{page_size} && $opts{page_size} != 0)
-        {
+    while ( my $r = $results->next_result ) {
+        push( @r, $r );
+        if ( ++$count >= $opts{page_size} && $opts{page_size} != 0 ) {
             last;
         }
     }
 
     my $pager;
 
-    unless ($opts{page_size} == 0)
-    {
+    unless ( $opts{page_size} == 0 ) {
 
-        $pager =
-          Data::Pageset->new(
-                             {
-                              total_entries    => $results->Hits,
-                              entries_per_page => $opts{page_size},
-                              current_page     => $opts{page},
-                              pages_per_set    => $opts{pages_per_set},
-                              mode             => 'slide',
-                             }
-                            );
+        $pager = Data::Pageset->new(
+            {   total_entries    => $results->Hits,
+                entries_per_page => $opts{page_size},
+                current_page     => $opts{page},
+                pages_per_set    => $opts{pages_per_set},
+                mode             => 'slide',
+            }
+        );
 
     }
 
     my $build_time = sprintf(
-                             '%0.4f',
-                             Time::HiRes::tv_interval(
-                                      $start_time, [Time::HiRes::gettimeofday()]
-                             )
-                            );
+        '%0.4f',
+        Time::HiRes::tv_interval(
+            $start_time, [ Time::HiRes::gettimeofday() ]
+        )
+    );
 
     return (
-            $pager,
-            \@r,
-            [$results->parsed_words($self->swish->indexes->[0])],
-            Sort::SQL->string2array($opts{order_by} || 'swishrank desc'),
-            $results->hits,
-            $search_time,
-            $build_time
-           );
+        $pager,
+        \@r,
+        [ $results->parsed_words( $self->swish->indexes->[0] ) ],
+        Sort::SQL->string2array( $opts{order_by} || 'swishrank desc' ),
+        $results->hits,
+        $search_time,
+        $build_time
+    );
 }
 
-sub _check_err
-{
+sub _check_err {
     my $self = shift;
 
-    if ($self->swish->error)
-    {
+    if ( $self->swish->error ) {
         $self->swish_error(
-                               ref($self) . ": "
-                             . $self->swish->error_string . ": "
-                             . $self->swish->last_error_msg);
+                  ref($self) . ": "
+                . $self->swish->error_string . ": "
+                . $self->swish->last_error_msg );
         return 1;
     }
     return 0;
@@ -338,23 +324,19 @@ since it inherits from SWISH::API::Stat.
 
 =cut
 
-sub connect
-{
+sub connect {
     my $self = shift;
-    $self->{swish} = SWISH::API::Object->new(%{$self->config});
+    $self->{swish} = SWISH::API::Object->new( %{ $self->config } );
     croak $self->swish_error if $self->_check_err;
 
     # use RankScheme 1 if the index supports it
-    my $rs =
-      $self->swish->header_value($self->swish->indexes->[0],
-                                 'IgnoreTotalWordCountWhenRanking');
-    if (!$rs)
-    {
+    my $rs = $self->swish->header_value( $self->swish->indexes->[0],
+        'IgnoreTotalWordCountWhenRanking' );
+    if ( !$rs ) {
         $self->swish->rank_scheme(1);
     }
 }
 
-
 1;
 
 __END__
